#include <bc_led_disp.h>

#include <SoftwareSerial.h>

SoftwareSerial swSerial(11, 12);  // rx, tx
BcLedDisp Disp(swSerial);   // 显示驱动实例

const unsigned char rotatingSegs[20] = {
  1, 2, 3, 11, 19, 27, 35, 43, 51, 59, 60, 61, 56, 48, 40, 32, 24, 16, 8, 0
};    // 光点位置表
int Counter;
int i;
unsigned char j;
char adjStep;
char Brightness;

void setup() {
  // put your setup code here, to run once:
  swSerial.begin(9600);   // 软件串口初始化
  Disp.clear();   // 清除显示
}

void loop() {
  // put your main code here, to run repeatedly:
  Counter = 0;
  for (i=0; i<0x200; i++) {   // 从0计数到0x200
    Counter = Counter+1;
    Disp.displayDec(Counter, 0, 3);   // 在第0位按10进制显示，显示宽度3位
    Disp.displayHex(Counter, 4, 4);   // 在第4位按16进制显示，显示宽度4位
  }
  delay(2000);    // 等待2秒
  Disp.clear();
  for (i=0; i<5; i++) {   // 重复5次（光点旋转5圈）
    for (j=0; j<20; j++) {
      Disp.sendCmd(SEG_ON, rotatingSegs[j]);    // 点亮一个显示段
      delay(25);    // 持续25ms
      Disp.sendCmd(SEG_OFF, rotatingSegs[j]);   // 关闭该显示段
    }
  }
  delay(300);
  for (i=0; i<5; i++) {   // 反向再重复5次
    for (j=0; j<20; j++) {
      Disp.sendCmd(SEG_ON, rotatingSegs[19-j]);
      delay(25);
      Disp.sendCmd(SEG_OFF, rotatingSegs[19-j]);
    }
  }
  Disp.displayDec(12345678, 0, 8);    // 显示12345678
  Disp.sendCmd(SEG_ON, 31);   // 点亮小数点
  Disp.sendCmd(BLINK_WT_SET+3, 0x80);   // 设置小数点闪烁
  delay(3000);    // 等待3s
  Disp.clear();
  Counter = 0;
  Brightness = 0;
  adjStep = 1;
  Disp.sendCmd(DIRECT_WT+7, 0x7c);  // 'b'    // 使用直接写入显示寄存器方式显示特殊字符“brt=”
  Disp.sendCmd(DIRECT_WT+6, 0x50);  // 'r'
  Disp.sendCmd(DIRECT_WT+5, 0x78);  // 't.'
  Disp.sendCmd(DIRECT_WT+4, 0x48);  // '='
  Disp.digitBlink(7, 1);    // "brt" 三个字符闪烁
  Disp.digitBlink(6, 1);
  Disp.digitBlink(5, 1);
  Disp.displayHex(Brightness, 3, 1);
  while (Counter != 1500) {   // 亮度电话重复30次 (显示亮度共16档，每计数50变化一档，往复各变化15次)
    Counter = Counter + 1;
    Disp.displayDec(Counter, 0, 2|0x80);    // 在第0位显示计数，2位显示，不消除前导0
    if ((Counter%50) == 0) {
      Brightness = Brightness + adjStep;    // 亮度值每计数50次改变一次
      Disp.sendCmd(DIM_CTL, Brightness);    // 调整显示亮度
      Disp.displayHex(Brightness, 3, 1);    // 亮度值显示在第3位，按16进制显示，显示宽度1位
      if (Brightness == 15) {   // 亮度值达到15后改为逐步减小
        adjStep = -1;
      }
      if (Brightness == 0) {    // 亮度值达到0后改为增加
        adjStep = 1;
      }
    }
    delay(50);
  }
  delay(2000);
  Disp.sendCmd(DIM_CTL, 0);
  Disp.clear();
}
