#include <bc_led_disp.h>

#include <bc_key_scan.h>

#include <SoftwareSerial.h>

SoftwareSerial  swSerial(11,12);  // rx,tx
BcKeyScan  Keypad(swSerial);    // 创建键盘实例
BcLedDisp  Disp(swSerial);    // 创建显示实例

unsigned char cnt1, cnt2;
unsigned char keyValue;
const unsigned char cb1[4] = {2, 100, 3, 17};   // 组合键1定义，由3键和17键2个键组成，分配键值100
const unsigned char cb2[4] = {2, 101, 3, 18};   // 组合键2定义，由3键和18键2个键组成，分配键值101
const unsigned char* CBList[2] = {cb1, cb2};    // 组合键列表
const unsigned char lp1[2] = {17, 120};   // 长按键1定义，为17键，分配键值120
const unsigned char lp2[2] = {18, 121};   // 长按键2定义，为18键，分配键值121
const unsigned char lp3[2] = {100, 122};  // 长按键3定义，为前面定义的3键和17键的组合键(键值100)，长按键分配键值122
const unsigned char lp4[2] = {101, 123};  // 长按键4定义，为前面定义的3键和18键的组合键(键值101)，长按键分配键值123
const unsigned char* LPList[4] = {lp1, lp2, lp3, lp4};    // 长按键列表

void setup() {
  swSerial.begin(9600);   // 软件串口初始化
  Keypad.setDetectMode(1);    // 设置检测按键释放
  Keypad.defCombinedKey(CBList, 2);   // 定义组合键
  Keypad.defLongpressKey(LPList, 4);  // 定义长按键
  Keypad.setLongpressCount(200);    // 设定长按键时间为2s(longpressTick()呼叫时间间隔为10ms，10ms*200=2s)
  Disp.clear();   // 清除显示
  cnt1 = 50;    // 两个显示数字的初始值均为50
  cnt2 = 50;
  Disp.displayDec(cnt1, 0, 3);    // 在第0位按10进制显示第一个数字，显示宽度为3位
  Disp.displayDec(cnt2, 4, 3);    // 在第4为按10进制显示第二个数字，显示宽度为3位
  Disp.sendCmd(BLINK_SPEED, 25);  // 设置闪烁速度
  Disp.digitBlink(0, 1);    // 设置第 0,1,2,4,5,6 位为闪烁显示
  Disp.digitBlink(1, 1);
  Disp.digitBlink(2, 1);
  Disp.digitBlink(4, 1);
  Disp.digitBlink(5, 1);
  Disp.digitBlink(6, 1);
}

void loop() {
  // put your main code here, to run repeatedly:
  Keypad.checkChanges();    // 更新键盘状态
  if (Keypad.isKeyChanged())    // 检查是否有新按键
  {
     keyValue = Keypad.getKeyValue();   // 如果有新按键，获取键值
     switch (keyValue) {
      case 17:    // 如果是17键
        if (cnt1 < 100) {   // 如果数字1小于100,数字1加1
          cnt1 = cnt1 + 1;
        }
        Disp.displayDec(cnt1, 0, 3);    // 更新数字1显示
        break;
      case 18:    // 如果是18键
        if (cnt1 > 0) {    // 如果数字1大于0,则数字1减1
          cnt1 = cnt1 - 1;
        }
        Disp.displayDec(cnt1, 0, 3);
        break;
      case 100:   // 如果键值是100 (3键和17键的组合键)
        if (cnt2 < 100) {   // 如果数字2小于100,数字2加1
          cnt2 = cnt2 + 1;
        }
        Disp.displayDec(cnt2, 4, 3);    // 在第4位按10进制显示数字2,显示宽度3位
        break;
      case 101:   // 如果键值是101 (3键和18键的组合键)
        if (cnt2 > 0) {   // 如果数字2大于0, 数字2减1
          cnt2 = cnt2 - 1;
        }
        Disp.displayDec(cnt2, 4, 3);
        break;
      case 120:   // 如果键值是120 (17键长按)
        Disp.digitBlink(0, 0);    // 位0,1,2停止闪烁
        Disp.digitBlink(1, 0);
        Disp.digitBlink(2, 0);
        while (Keypad.getKeyValue() == keyValue) {    // 如果读到键值一直没变化，表示长按键一直有效(因为设置了检测按键释放，长按键放开时会有不同键值)
          if (cnt1 < 100) {   // 数字1快速增加(间隔200ms)
            cnt1 = cnt1 + 1;
            Disp.displayDec(cnt1, 0, 3);
          }
          delay(200);   // 数字增加时间间隔200ms
          Keypad.checkChanges();    // 必须更新键盘状态，否则驱动库不会检测到键盘变化
        }
        Disp.digitBlink(0, 1);    // 长按键释放，恢复闪烁显示
        Disp.digitBlink(1, 1);
        Disp.digitBlink(2, 1);
        break;
      case 121:   // 如果键值是121 (18键长按)
        Disp.digitBlink(0, 0);
        Disp.digitBlink(1, 0);
        Disp.digitBlink(2, 0);
        while (Keypad.getKeyValue() == keyValue) {
          if (cnt1 > 0) {
            cnt1 = cnt1 - 1;
            Disp.displayDec(cnt1, 0, 3);
          }
          delay(200);
          Keypad.checkChanges();
        }
        Disp.digitBlink(0, 1);
        Disp.digitBlink(1, 1);
        Disp.digitBlink(2, 1);
        break;
      case 122:   // 如果键值是122 (3键和17键的组合键长按)
        Disp.digitBlink(4, 0);
        Disp.digitBlink(5, 0);
        Disp.digitBlink(6, 0);
        while (Keypad.getKeyValue() == keyValue) {
          if (cnt2 < 100) {
            cnt2 = cnt2 + 1;
            Disp.displayDec(cnt2, 4, 3);
          }
          delay(200);
          Keypad.checkChanges();
        }
        Disp.digitBlink(4, 1);
        Disp.digitBlink(5, 1);
        Disp.digitBlink(6, 1);
        break;
      case 123:   // 如果键值是123 (3键和18键的组合键长按)
        Disp.digitBlink(4, 0);
        Disp.digitBlink(5, 0);
        Disp.digitBlink(6, 0);
        while (Keypad.getKeyValue() == keyValue) {
          if (cnt2 != 0) {
            cnt2 = cnt2 - 1;
            Disp.displayDec(cnt2, 4, 3);
          }
          delay(200);
          Keypad.checkChanges();
        }
        Disp.digitBlink(4, 1);
        Disp.digitBlink(5, 1);
        Disp.digitBlink(6, 1);
        break;
      default:
        break;
     }
  }
  Keypad.longpressTick();   // 长按键计数
  delay(10);    // 每次长按键计数时间间隔10ms
}
